@@ -120,10 +120,13 @@ EXTENSIONS = {
     'lean': {'text', 'lean'},
     'lektorproject': {'text', 'ini', 'lektorproject'},
     'less': {'text', 'less'},
+    'lfm': {'text', 'lazarus', 'lazarus-form'},
     'lhs': {'text', 'literate-haskell'},
     'libsonnet': {'text', 'jsonnet'},
     'lidr': {'text', 'idris'},
     'liquid': {'text', 'liquid'},
+    'lpi': {'text', 'lazarus', 'xml'},
+    'lpr': {'text', 'lazarus', 'pascal'},
     'lr': {'text', 'lektor'},
     'lua': {'text', 'lua'},
     'm': {'text', 'objective-c'},
@@ -151,6 +154,7 @@ EXTENSIONS = {
     'njk': {'text', 'nunjucks'},
     'otf': {'binary', 'otf'},
     'p12': {'binary', 'p12'},
+    'pas': {'text', 'pascal'},
     'patch': {'text', 'diff'},
     'pdf': {'binary', 'pdf'},
     'pem': {'text', 'pem'},
@@ -168,6 +172,7 @@ EXTENSIONS = {
     'properties': {'text', 'java-properties'},
     'proto': {'text', 'proto'},
     'ps1': {'text', 'powershell'},
+    'pug': {'text', 'pug'},
     'puml': {'text', 'plantuml'},
     'purs': {'text', 'purescript'},
     'pxd': {'text', 'cython'},
